# crypto-strategy
[![pages-build-deployment](https://github.com/minggnim/crypto-strategy/actions/workflows/pages/pages-build-deployment/badge.svg)](https://github.com/minggnim/crypto-strategy/actions/workflows/pages/pages-build-deployment)
[![pypi-upload](https://github.com/minggnim/crypto-strategy/actions/workflows/python-publish.yml/badge.svg)](https://github.com/minggnim/crypto-strategy/actions/workflows/python-publish.yml)

![](./img/algo-trading.png)

A repo to create trading strategies for cryptocurrencies.

## Install

pip install crypto-strategy[full]

## Usage

